@@ -3,16 +3,17 @@
 
 import click
 
-from blackcap import global_config
-from blackcap.extensions import messenger
+from blackcap.configs import config_registry
+from blackcap.messenger import messenger_registry
 
 from logzero import logger
 
+config = config_registry.get_config()
+messenger = messenger_registry.get_messenger(config.MESSENGER)
+
 
 @click.command()
-@click.option(
-    "--sub_id", default=global_config.GCP_PUBSUB_SUB_ID, help="Subscription Id"
-)
+@click.option("--sub_id", default=config.GCP_PUBSUB_SUB_ID, help="Subscription Id")
 def echo(sub_id: str) -> None:
     """subscribe and echo msgs"""
     logger.info("Trying to subscribe and read messages...")
@@ -23,9 +24,7 @@ def echo(sub_id: str) -> None:
 
 
 @click.command()
-@click.option(
-    "--sub_id", default=global_config.GCP_PUBSUB_SUB_ID, help="Subscription Id"
-)
+@click.option("--sub_id", default=config.GCP_PUBSUB_SUB_ID, help="Subscription Id")
 def schedule(sub_id: str) -> None:
     """subscribe and save msgs to DB"""
     logger.info("Trying to subscribe and read messages...")
